@@ -45,11 +45,19 @@ from sphinx.locale import _
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.4.0"
+__version__: str = "0.4.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["FixtureDecoratorFinder", "FixtureDocumenter", "is_fixture", "setup"]
 
+try:  # pragma: no cover
+	# 3rd party
+	from _pytest.fixtures import FixtureFunctionDefinition  # type: ignore[attr-defined]
+except ImportError:  # pragma: no cover
+
+	class FixtureFunctionDefinition:  # type: ignore[no-redef]
+		pass
+
 
 class FixtureDecoratorFinder(ast.NodeVisitor):
 	"""
@@ -160,7 +168,7 @@ class FixtureDocumenter(FunctionDocumenter):
 		:param parent: The parent of the member.
 		"""
 
-		if isinstance(member, FunctionType):
+		if isinstance(member, (FunctionType, FixtureFunctionDefinition)):
 			return is_fixture(member)[0]
 		else:  # pragma: no cover
 			return False
